==> octave-2.1.30.tgz: include/octave-2.1.30/octave/mx-ext.h <==
/*

Copyright (C) 1996, 1997 John W. Eaton

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, write to the Free
Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#if !defined (octave_mx_ext_h)
#define octave_mx_ext_h 1

// Result of a AEP Balance operation.

#include "dbleAEPBAL.h"
#include "CmplxAEPBAL.h"

// Result of a Determinant calculation.

#include "dbleDET.h"
#include "CmplxDET.h"

// Result of a Cholesky Factorization

#include "dbleCHOL.h"
#include "CmplxCHOL.h"

// Result of a Hessenberg Decomposition

#include "dbleHESS.h"
#include "CmplxHESS.h"

// Result of a Schur Decomposition

#include "dbleSCHUR.h"
#include "CmplxSCHUR.h"

// Result of a Singular Value Decomposition.

#include "dbleSVD.h"
#include "CmplxSVD.h"

// Result of an Eigenvalue computation.

#include "EIG.h"

// Result of an LU decomposition.

#include "dbleLU.h"
#include "CmplxLU.h"

// Result of a QR decomposition.

#include "dbleQR.h"
#include "CmplxQR.h"

#endif

/*
;;; Local Variables: ***
;;; mode: C++ ***
;;; End: ***
*/

==> octave-2.1.72p6.tgz: include/octave-2.1.72/octave/mx-ext.h <==
/*

Copyright (C) 1996, 1997 John W. Eaton

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, write to the Free
Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301, USA.

*/

#if !defined (octave_mx_ext_h)
#define octave_mx_ext_h 1

// Result of a AEP Balance operation.

#include "dbleAEPBAL.h"
#include "CmplxAEPBAL.h"

// Result of a Determinant calculation.

#include "dbleDET.h"
#include "CmplxDET.h"

// Result of a Cholesky Factorization

#include "dbleCHOL.h"
#include "CmplxCHOL.h"

// Result of a Hessenberg Decomposition

#include "dbleHESS.h"
#include "CmplxHESS.h"

// Result of a Schur Decomposition

#include "dbleSCHUR.h"
#include "CmplxSCHUR.h"

// Result of a Singular Value Decomposition.

#include "dbleSVD.h"
#include "CmplxSVD.h"

// Result of an Eigenvalue computation.

#include "EIG.h"

// Result of an LU decomposition.

#include "dbleLU.h"
#include "CmplxLU.h"

// Result of a QR decomposition.

#include "dbleQR.h"
#include "CmplxQR.h"

#include "dbleQRP.h"
#include "CmplxQRP.h"

#endif

/*
;;; Local Variables: ***
;;; mode: C++ ***
;;; End: ***
*/
